Usage
=====

.. _installation:

Installation
------------

To use PlasmaCalcs, first install it using pip:

.. code-block:: console

   pip install plasmacalcs


Or, get the latest version from source:

.. code-block:: console

   git clone https://gitlab.com/Sevans7/plasmacalcs
   cd plasmacalcs
   pip install .


Please take a look at the README for more details, at: https://gitlab.com/Sevans7/plasmacalcs
